---
title: Setup Linux Environment
summary: How to create the C++ build environment on Linux Systems
authors:
    - Sebastian Oberschwendtner
date: 2024-03-01
---
## Introduction
We use the basic linux tools to build *UNICADO* on Linux.
The tools used are:

- Compiler: `GCC` + `make`
- Generator tool: `CMake` (more infos [here](../build/general.md))
- Package manager: &rarr; The package manager of your **Linux** distribution should suffice
- some other tools (Python, Git - see below)

>You can use _Visual Studio Code_ as your IDE which will integrate everything, but since we are not prescribing any IDE, this will only show you how to setup the build tools. :point_up:

---

## Install Build Tools
Since there are many distributions out there and they all call the package which contains all build tools differently, we can provide just a small set of examples.
If you distribution is not listed here, make sure you at least install:

- `gcc` + `g++`
- `make`
- `gdb`
- `git`

=== "Arch"

    ```{.sh .copy}
    sudo pacman -Sy
    sudo pacman -S devtools
    ```

=== "Ubuntu"

    ```{.sh .copy}
    sudo apt-get update
    sudo apt-get install build-essential
    ```
---

## Install Other Tools
Please install the following as well:

|Package|Version|
|---|---|
|`git`| |
|`python`| Preferably **3.11**|
|`pyenv`| |
|`cmake`| >= **3.29**|
|`matplotplusplus`| |

For Python, you can install it:
=== "Arch"

    ```{.sh .copy}
    sudo pacman -S pyenv
    pyenv install 3.11.10
    ```

!!! important 
    Currently, `matplotplusplus` has to be cloned manually into the submodule `aircraftdesign`. Sometimes here are connection problems when doing so. The command that currently works is 
    ```{.sh .copy}
    git clone --depth=1 --shallow-submodules https://github.com/alandefreitas/matplotplusplus.git 
    ```