---
title: Building Python Modules
summary: How to build Python modules of UNICADO.
authors:
    - Sebastian Oberschwendtner
    - Kristina Mazur
date: 2024-11-05
---
> :construction: tbd

Some modules are written in Python. Although, the tools can run without Cmake, the recommended way is to still use it to create the virtual environment (at least for configuration!). However, if you are an expert, feel free to do it by yourself :material-arm-flex: !

In the following, it is explained how to [configure](#configure) and [build](#build) with CMake. It is pretty straight-forward as it is the same procedure as for C++ - just with one slight addition!

!!! note
    The required setup for Python including the `pipenv` dependency was already explained in the [developer prerequisites](../build-environment/windows.md).

## Configure

This is just a short recap as more information are given in the C++ section.

1. Open a terminal inside the root directory of the *rAircraftDesign* repository.
2. Configure **CMake** by explicitly telling it which preset to use:

=== "Windows"

    ``` { .sh .copy }
    cmake --preset x64-windows-release
    ```

=== "MinGW"

    ``` { .sh .copy }
    cmake --preset x64-mingw-release
    ```
=== "Linux"

    ``` { .sh .copy }
    cmake --preset x64-linux-release
    ```

The libraries that are defined in the `Pipfile` are the ones installed in your environment.

!!! tip
    In case you want to checkout your virtual environment, you usually can find it in your user directory in .virtualenvs

## Build

### Install python packages

Now this is the difference to the Cpp tools. The python tools use some of the Cpp libraries, which have to be installed via the python bindings. To do so you need to add them into your virtual environment.

=== "Windows"

    ```sh
    cmake --build --preset x64-windows-release -t install_python_package
    ```

=== "MinGW"

    ```sh
    cmake --build --preset x64-mingw-release -t install_python_package
    ```

    !!! tip
        Remember: The build preset should match the one specified when configuring **CMake** :point_up:.

=== "Unix"

    ```sh
    cmake --build --preset x64-linux-release -t install_python_package
    ```

    !!! tip
        Remember: The build preset should match the one specified when configuring **CMake** :point_up:.


### Build target

Same as for Cpp:

=== "Windows"

    ```sh
    cmake --build --preset x64-windows-release --target <target>
    ```

=== "MinGW"

    ```sh
    cmake --build --preset x64-mingw-release --target <target>
    ```

    !!! tip
        Remember: The build preset should match the one specified when configuring **CMake** :point_up:.

=== "Unix"

    ```sh
    cmake --build --preset x64-linux-release --target <target>
    ```

    !!! tip
        Remember: The build preset should match the one specified when configuring **CMake** :point_up:.
