---
title: Analysis
summary: Overview of the analysis modules of aircraftDesign repository
authors:
    - Sebastian Oberschwendtner
date: 2023-09-08
glightbox: false
---
# Analysis Tools

---

## calculateEmissions
![Icon](../assets/images/documentation/calculate-emissions.svg){.overview-img  align=left}
The **calculateEmissions** is an additional module of the UNICADO toolchain.
Its purpose is to calculate the emissions and energy demand within the aircraft's lifecycle and to determine the missions based climate impact.
For the user, possible changes in the module run configuration can be made in the related calculateEmissions_conf.xml file.
The parameters comprised in this XML file can have different attributes as e.g. Filenames, Directories, Output configs, and are further subdivided into control and program settings.
{.overview-item}

!!! note
    By now, only the calculation routines / outputs based on the flown mission are up to date.

|Module Version|Language|License|Documentation|
|:---:|:---:|:---:|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link]()|

---

## calculatePerformance
![Icon](../assets/images/documentation/calculate-performance.svg){.overview-img  align=left}
The module `calculatePerformance` is used to evaluate the mission performance of the design.
{.overview-item}

|Module Version|Language|License|Documentation|
|:---:|:---:|:---:|---|
|2.1.0|:simple-cplusplus:| GPLv3 |[Link]()|

---

## calculatePolar
![Icon](../assets/images/documentation/calculate-polar.svg){.overview-img  align=left}
The tool `calculatePolar` calculates, as the tool name suggests, the polars of an aircraft.
CalculatePolar uses the tool Lifting Line from DLR to calculate force, lift and moment coefficients for each lifting surface of the aircraft.
These coefficients are used to calculate induced, viscous and wave drag as well as the moment coefficients for the overall aircraft.
Furthermore polars are not only calculated for off-design mach numbers but also for high
lift mach numbers.
{.overview-item}

|Module Version|Language|License|Documentation|
|:---:|:---:|:---:|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link]()|

---

## costEstimation
![Icon](../assets/images/documentation/cost-estimation.svg){.overview-img  align=left}
This modules calculates the direct operating cost (DOC) of an aircraft.
Direct costs include all expenses incurred in operating and financing the aircraft:

- Fuel
- Crew
- Maintenance
- Fees

|Module Version|Language|License|Documentation|
|:---:|:---:|:---:|---|
|2.1.0|:simple-python: |GPLv3|[Link]()|

---

## massEstimation
![Icon](../assets/images/documentation/mass-estimation.svg){.overview-img  align=left}
The Mass Estimation module calculates sub-masses and total masses of the aircraft including center of gravities.
{.overview-item}

|Module Version|Language|License|Documentation|
|:---:|:---:|:---:|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link]()|

---

## missionAnalysis
![Icon](../assets/images/documentation/mission-analysis.png){.overview-img  align=left}
The module `missionAnalysis` is the key module of the aircraft performance analysis.
Its purpose is to calculate the flight trajectory, based on the inputs of the preliminary aircraft design cycle, by solving the aircraft equations of motion being simplified as a point mass model.
Depending on the method, the fuel consumption is calculated either:

- in segments by using the Breguet range formula, or
- in a full-mission time-history simulation (the flight mission is divided into increments. For each increment the movement equations are solved, followed by the thrust requirements and fuel consumption)

For the user, possible changes in the module run configuration can be made in the related *missionAnalysis_conf.xml* file. The parameters comprised in this XML file can have different attributes as e.g. Desc, Unit, Default, AllowedRelOvershoot or text and are further subdivided into control and program settings.

|Module Version|Language|License|Documentation|
|:---:|:---:|:---:|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link]()|

---