---
title: Libraries
summary: Overview of the libraries respository
authors:
    - Sebastian Oberschwendtner
date: 2023-09-08
glightbox: false
---

## aerodynamics
![Icon](../assets/images/documentation/aerodynamics.svg){.overview-img  align=left}
This library helps with interacting with polar data.
It has helper functions to extract and interpolate data of provided airfoil polars.
{.overview-item}

|Module Version|Language|License|Documentation|Dependencies|
|:---:|:---:|:---:|---|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link]()|-|

---

## aircraftGeometry
![Icon](../assets/images/documentation/aircraft-geometry.svg){.overview-img  align=left}
This library defines geometry classes which are generally used within an aircraft.
The geometry describes the general shape of the different components.
The available components are:

- *liftingSurface*
- *verticalSurface*
- *Fuselage*
- *Nacelle*
- *Pylon*
- *Landing Gear*

The library furthermore provides functions to extract and measure geometry properties of the different shapes at certain locations.

|Module Version|Language|License|Documentation|Dependencies|
|:---:|:---:|:---:|---|---|
|2.0.0|:simple-cplusplus: |GPLv3|[Link]()|-|

---

## aircraftGeometry2
![Icon](../assets/images/logos/unicado-icon.png){.overview-img  align=left}
This library is based on the older [aircraftGeometry](#aircraftgeometry) library and extends it to be more modular.
The modularity and flexibility is achieved by using the high performance [Computational Geometry Algorithms Library](https://www.cgal.org/) also known as **CGAL**.
{.overview-item}

|Module Version|Language|License|Documentation|Dependencies|
|:---:|:---:|:---:|---|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link](aircraftGeometry2/index.html)| [Eigen3](https://eigen.tuxfamily.org/index.php?title=Main_Page), [CGAL](https://www.cgal.org/)|

---

## aircraftNetwork
![Icon](../assets/images/documentation/aircraft-network.svg){.overview-img  align=left}
This library can be used to define wiring harnesses within an existing aircraft geometry.
You can route wire through different points and analyse the resulting network.
{.overview-item}

|Module Version|Language|License|Documentation|Dependencies|
|:---:|:---:|:---:|---|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link]()|-|

---

## aixml
![Icon](../assets/images/documentation/aixml.svg){.overview-img  align=left}
The **aixml** library is the central library which handles the XML files and data access.
It uses a simple XML library, namely *tinyxml*, to read and parse the XML files.
{.overview-item}

|Module Version|Language|License|Documentation|Dependencies|
|:---:|:---:|:---:|---|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link]()|-|

---

## atmosphere
![Icon](../assets/images/documentation/atmosphere.svg){.overview-img  align=left}
The **atmosphere** library provides helper functions to calculate atmospheric properties according to the International Standard Atmosphere (*ISA*).
You can set different atmospheric conditions (e.g. *ISA+25*) and calculate the physical properties of the air at different altitudes.
{.overview-item}

|Module Version|Language|License|Documentation|Dependencies|
|:---:|:---:|:---:|---|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link]()||

---

## blackboxTest
![Icon](../assets/images/documentation/blackbox.svg){.overview-img  align=left}
The **blackboxTest** library provides an interface to run a complete module with different test cases and then checks whether a specific result is calculated or set compared to expected values defined in a `blackBoxTestCases.xml`. The tests are realized with the help of the _googleTest_ framework .
{.overview-item}

|Module Version|Language|License|Documentation|Dependencies|
|:---:|:---:|:---:|---|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link]()|[googleTest](https://google.github.io/googletest/)|

---

## engine
![Icon](../assets/images/documentation/engine.svg){.overview-img  align=left}
This library helps with interacting with engine data.
It has helper functions to extract and interpolate data of provided engine data decks.
The engine decks can originate from different softwaretools as long as they provide the same file format.
{.overview-item}

|Module Version|Language|License|Documentation|Dependencies|
|:---:|:---:|:---:|---|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link](EngineLib/index.html)|-|

---

## liftingLineInterface
![Icon](../assets/images/documentation/lifting-line.svg){.overview-img  align=left}
This library helps with interacting with results provided by the tools **Lifting Line** from DLR.
It has helper functions to extract and interpolate data of the results from the tool.
{.overview-item}

|Module Version|Language|License|Documentation|Dependencies|
|:---:|:---:|:---:|---|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link]()|-|

---

## moduleBasics
![Icon](../assets/images/documentation/module-basics.svg){.overview-img  align=left}
This library provides the basis structure for the modular approach of the **UNICADO** tools.
The tools are intended to follow the *Strategy Design Pattern* to execute at different fidelity levels.
The library gives a template how modules should be structured and gives helpers which can be used to select and implement the different fidelity methods.
{.overview-item}

|Module Version|Language|License|Documentation|Dependencies|
|:---:|:---:|:---:|---|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link]()|-|

---

## propulsionsystem
![Icon](../assets/images/logos/unicado-icon.png){.overview-img  align=left}
This is a versatile tool which can be used to simulate and analyse the power flow within an aircraft.
The power flow is mainly determined by the propulsive systems onboard, but the tool can account for other power needed during operation as well.
The propulsion systems are not limited to conventional types.
Due to the flexible abstraction via so-called *two-terminal block*, any system which as inputs and outputs can be implemented.
{.overview-item}

|Module Version|Language|License|Documentation|Dependencies|
|:---:|:---:|:---:|---|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link]()|-|

!!! info
    Since this is a standalone tool it will most likely move to another repository in the next release.

---

## runtimeInfo
![Icon](../assets/images/documentation/runtime-info.svg){.overview-img  align=left}
This library handles the user interface during the modules execution.
In provides custom output streams, which automatically handle the log files and error outputs according to the configuration files.
{.overview-item}

|Module Version|Language|License|Documentation|Dependencies|
|:---:|:---:|:---:|---|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link]()|-|

---

## spline
![Icon](../assets/images/documentation/spline.svg){.overview-img  align=left}
The name gives it away: this library provides spline functionality for interpolating data or geometry.
{.overview-item}

|Module Version|Language|License|Documentation|Dependencies|
|:---:|:---:|:---:|---|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link]()|-|

---

## standardFiles
![Icon](../assets/images/documentation/standard-files.svg){.overview-img  align=left}
This library provides file interfaces and interacts with the operating system.
It can handle process execution with a simple interface.
The library can handle *UNIX* and *Windows* systems alike.
{.overview-item}

|Module Version|Language|License|Documentation|Dependencies|
|:---:|:---:|:---:|---|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link]()|-|

!!! warning
    Some functions of this library are a bit outdated! When using this library, please look first at the wonderful [STL :octicons-link-external-16:](https://en.cppreference.com/w/) whether the function you are seeking is already there.

---

## svgPlot
![Icon](../assets/images/documentation/svg-plot.svg){.overview-img  align=left}
This library interact with the shapes defined by [aircraftGeometry](#aircraftgeometry) and can create different views of the shapes in **SVG** format.
You can insert text and measurements for quickly creating meaningful reports.
{.overview-item}

|Module Version|Language|License|Documentation|Dependencies|
|:---:|:---:|:---:|---|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link]()|-|

---

## unitConversion
![Icon](../assets/images/documentation/unit-conversion.svg){.overview-img  align=left}
The **unitConversion** groups the most commonly used unit in aerospace and let's you convert values from one unit to another.
In addition, it defines some common **constants** which are useful for calculations.
{.overview-item}

|Module Version|Language|License|Documentation|Dependencies|
|:---:|:---:|:---:|---|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link]()|-|